| frab | R Documentation |
frab objectsPackage idiom for creating frab objects
frab(x)
as.frab(x)
is.frab(x)
list_to_frab(L)
x |
object coerced to, or tested for, |
L |
List of two elements, a numeric vector named |
Function frab() is the creation method, taking a named numeric
vector as its argument; it is the only function in the package that
actually calls new("frab", ...).
Function as.frab() tries a bit harder to be useful and can coerce
different types of object to a frab. If given a list it
dispatches to list_to_frab(). If given a table it dispatches to
table_to_frab(), documented at table.Rd; and if given a
data frame it dispatches to df_to_frab(), documented at
dataframe.Rd.
Returns a frab, or a boolean
Robin K. S. Hankin
frab-class
frab(c(x=6,y=6,z=-4,u=0,x=3))
as.frab(c(a=2,b=1,c=77))
as.frab(list(names=letters[5:2],values=1:4))
x <- rfrab()
y <- rfrab()
x+y
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.