Learn R Programming

frab (version 0.0-6)

pmax: Parallel maxima and minima for frabs

Description

Parallel (pairwise) maxima and minima for frabs.

Usage

pmax_pair(F1,F2)
pmin_pair(F1,F2)
pmax_dots(x, ...)
pmin_dots(x, ...)
# S4 method for frab
pmax(...)
# S4 method for frab
pmin(...)

Value

Returns a frab object

Arguments

F1, F2, x, ...

Frab objects

Author

Robin K. S. Hankin

Details

Pairwise minima and maxima for frabs, using names as the primary key.

Functions pmax_pair() calls c_frab_pmax() and pmin_pair() use

Functions pmax() and pmin() use the same mechanism as cbrob() of the Brobdingnag package, originally due to John Chambers (pers. comm.)

Examples

Run this code

x <- rfrab()
y <- rfrab()

Run the code above in your browser using DataLab